==> QMK-Groundstation-v0.2.1.tar.gz: QMK-Groundstation-v0.2.1/global.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Manuel Schrape                                  *
 *   manuel.schrape@gmx.de                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License.        *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef GLOBAL_H
#define GLOBAL_H

#include <QString>

static const int FC_VERSION = 8;

static const QString QA_NAME = "QMK-Groundstation";
static const QString QA_VERSION = "0.2.1";
static const QString QA_DATE = "18.09.2008";
static const QString QA_YEAR = "2008";
static const QString QA_AUTHOR = "Manuel Schrape";

static const int MaxParameter = 83;

static const int P_KANAL_GAS   = 0;
static const int P_KANAL_GIER  = 1;
static const int P_KANAL_NICK  = 2;
static const int P_KANAL_ROLL  = 3;
static const int P_KANAL_POTI1 = 4;
static const int P_KANAL_POTI2 = 5;
static const int P_KANAL_POTI3 = 6;
static const int P_KANAL_POTI4 = 7;
static const int P_GLOBAL_CONF = 8;
static const int P_MIN_GAS     = 9;

static const int P_DRUCK_D       = 10;
static const int P_MAXHOEHE      = 11;
static const int P_HOEHE_P       = 12;
static const int P_HOEHE_GAIN    = 13;
static const int P_HOEHE_ACC     = 14;
static const int P_STICK_P       = 15;
static const int P_STICK_D       = 16;
static const int P_GIER_P        = 17;
static const int P_GAS_MAX       = 18;
static const int P_GAS_MIN       = 19;

static const int P_GYRO_ACC_FAKTOR = 20;
static const int P_KOMPASS_WIRKUNG = 21;
static const int P_GYRO_P          = 22;
static const int P_GYRO_I          = 23;
static const int P_UNTERSPANNUNG   = 24;
static const int P_NOTGAS          = 25;
static const int P_NOTGASZEIT      = 26;
static const int P_AUSRICHTUNG     = 27;
static const int P_FAKTOR_I        = 28;
static const int P_USER_1          = 29;

static const int P_USER_2          = 30;
static const int P_USER_3          = 31;
static const int P_USER_4          = 32;
static const int P_SERVO_NICK_CONT = 33;
static const int P_SERVO_NICK_COMP = 34;
static const int P_SERVO_NICK_MIN  = 35;
static const int P_SERVO_NICK_MAX  = 36;
static const int P_SERVO_NICK_REFR = 37;
static const int P_LOOP_GAS_LIMIT  = 38;
static const int P_LOOP_THRESHOLD  = 39;

static const int P_LOOP_HYSTERESE  = 40;
static const int P_ACHS_KOPPLUNG   = 41;
static const int P_ACHS_GKOPPLUNG  = 42;
static const int P_WINKEL_NICK     = 43;
static const int P_WINKEL_ROLL     = 44;
static const int P_GYRO_ACC_ABGL   = 45;
static const int P_DRIFT_KOMP      = 46;
static const int P_DYNAMIC_STAB    = 47;
static const int P_USER_5          = 48;
static const int P_USER_6          = 49;

static const int P_USER_7          = 50;
static const int P_USER_8          = 51;
static const int P_J16_BITMASK     = 52;
static const int P_J16_TIMING      = 53;
static const int P_J17_BITMASK     = 54;
static const int P_J17_TIMING      = 55;
static const int P_NAV_GPS_MODE    = 56;
static const int P_NAV_GPS_GAIN    = 57;
static const int P_NAV_GPS_P       = 58;
static const int P_NAV_GPS_I       = 59;

static const int P_NAV_GPS_D        = 60;
static const int P_NAV_GPS_ACC      = 61;
static const int P_NAV_GPS_MIN      = 62;
static const int P_NAV_STICK_THRE   = 63;
static const int P_EXTERNAL         = 64;
static const int P_LOOP_CONFIG      = 65;
static const int P_SERVO_NICK_COMPI = 66;
static const int P_RESERVED         = 67;
static const int P_NAME             = 71;

#endif

==> QMK-Groundstation-v0.5.0.tar.gz: QMK-Groundstation-v0.5.0/global.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Manuel Schrape                                  *
 *   manuel.schrape@gmx.de                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License.        *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef GLOBAL_H
#define GLOBAL_H

#include <QString>
#include <QSize>
#include <QPoint>
#include <QColor>

static const int FC_VERSION = 8;

static const QString QA_NAME = "QMK-Groundstation";
static const QString QA_VERSION = "0.5.0";
static const QString QA_DATE = "05.10.2008";
static const QString QA_YEAR = "2008";
static const QString QA_AUTHOR = "Manuel Schrape";
static const QString QA_EMAIL  = "manuel.schrape@gmx.de";


static const QString QA_ABOUT =
    "<HTML>"
    "<p><b><font size=8>" + QA_NAME + "</font></b></p>"
    "<br />"
    "Version " + QA_VERSION + " - " + QA_DATE + ""
    "<br /><br />"
    "(C) " + QA_YEAR + " by " + QA_AUTHOR + " - "
    "<a href=\"mailto:" + QA_EMAIL + "\">" + QA_EMAIL + "</a> <br /><br />"
    "Groundstation-Programm f&uuml;r den Mikrokopter zum <br>Parametrieren und Debug-Werte anzeigen, aufzeichnen & Visualisieren."
    "</HTML>";

static const QString Def_AnalogNames[] = {"Integral Nick", "Integral Roll", "ACC Nick", "ACC Roll", "Gyro Gier", "Hoehen-Wert", "ACC Z", "GAS", "Kompass-Value", "Spannung", "Empfang", "Ersatzkompass", "Motor Vorne", "Motor Hinten", "Motor Links", "Motor Rechts", "Analog 16", "Distance", "OSD-Bar", "MK3Mag", "Servo", "Nick", "Roll", "Analog 23", "Analog 24",  "Analog 25",  "Analog 26",  "Analog 27",  "Analog 28",  "Analog 29", "GPS Nick", "GPS Roll"};

static const QRgb Def_Colors[] = {0x00FF0000, 0x0000FF00, 0x00FFFF00, 0x000000FF, 0x00FF00FF, 0x0000FFFF, 0x00FFFFFF, 0x00660000, 0x00006600, 0x00666600, 0x00000066, 0x00660066, 0x000066, 0x00666666, 0x00990000, 0x00009900, 0x00999900, 0x00000099, 0x00990099, 0x00009999, 0x00999999, 0x00CC0000, 0x0000CC00, 0x00CCCC00, 0x000000CC, 0x00CC00CC, 0x0000CCCC, 0x00CCCCCC, 0x0066FF99, 0x009966FF, 0x00FF9966, 0x0099FF66};

static const bool Def_Plot_Show[] = {1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0};
static const bool Def_Log[]       = {1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0};

static const int MaxAnalog    = 32;
static const int MaxPlot      = 50000;
static const int PlotWide     = 50;

static const int MaxParameter = 83;

static const int P_KANAL_GAS   = 0;
static const int P_KANAL_GIER  = 1;
static const int P_KANAL_NICK  = 2;
static const int P_KANAL_ROLL  = 3;
static const int P_KANAL_POTI1 = 4;
static const int P_KANAL_POTI2 = 5;
static const int P_KANAL_POTI3 = 6;
static const int P_KANAL_POTI4 = 7;
static const int P_GLOBAL_CONF = 8;
static const int P_MIN_GAS     = 9;

static const int P_DRUCK_D       = 10;
static const int P_MAXHOEHE      = 11;
static const int P_HOEHE_P       = 12;
static const int P_HOEHE_GAIN    = 13;
static const int P_HOEHE_ACC     = 14;
static const int P_STICK_P       = 15;
static const int P_STICK_D       = 16;
static const int P_GIER_P        = 17;
static const int P_GAS_MIN       = 18;
static const int P_GAS_MAX       = 19;

static const int P_GYRO_ACC_FAKTOR = 20;
static const int P_KOMPASS_WIRKUNG = 21;
static const int P_GYRO_P          = 22;
static const int P_GYRO_I          = 23;
static const int P_UNTERSPANNUNG   = 24;
static const int P_NOTGAS          = 25;
static const int P_NOTGASZEIT      = 26;
static const int P_AUSRICHTUNG     = 27;
static const int P_FAKTOR_I        = 28;
static const int P_USER_1          = 29;

static const int P_USER_2          = 30;
static const int P_USER_3          = 31;
static const int P_USER_4          = 32;
static const int P_SERVO_NICK_CONT = 33;
static const int P_SERVO_NICK_COMP = 34;
static const int P_SERVO_NICK_MIN  = 35;
static const int P_SERVO_NICK_MAX  = 36;
static const int P_SERVO_NICK_REFR = 37;
static const int P_LOOP_GAS_LIMIT  = 38;
static const int P_LOOP_THRESHOLD  = 39;

static const int P_LOOP_HYSTERESE  = 40;
static const int P_ACHS_KOPPLUNG   = 41;
static const int P_ACHS_GKOPPLUNG  = 42;
static const int P_WINKEL_NICK     = 43;
static const int P_WINKEL_ROLL     = 44;
static const int P_GYRO_ACC_ABGL   = 45;
static const int P_DRIFT_KOMP      = 46;
static const int P_DYNAMIC_STAB    = 47;
static const int P_USER_5          = 48;
static const int P_USER_6          = 49;

static const int P_USER_7          = 50;
static const int P_USER_8          = 51;
static const int P_J16_BITMASK     = 52;
static const int P_J16_TIMING      = 53;
static const int P_J17_BITMASK     = 54;
static const int P_J17_TIMING      = 55;
static const int P_NAV_GPS_MODE    = 56;
static const int P_NAV_GPS_GAIN    = 57;
static const int P_NAV_GPS_P       = 58;
static const int P_NAV_GPS_I       = 59;

static const int P_NAV_GPS_D        = 60;
static const int P_NAV_GPS_ACC      = 61;
static const int P_NAV_GPS_MIN      = 62;
static const int P_NAV_STICK_THRE   = 63;
static const int P_EXTERNAL         = 64;
static const int P_LOOP_CONFIG      = 65;
static const int P_SERVO_NICK_COMPI = 66;
static const int P_RESERVED         = 67;
static const int P_NAME             = 71;

struct set_TTY
{
    QString Port;
};

struct set_GUI
{
    bool   isMax;
    QSize  Size;
    QPoint Point;
};

struct set_DIR
{
    QString Logging;
    QString Parameter;
};

struct set_Analog
{
    QString   Name;
    bool      Log;
    bool      Plot;
    QColor    Color;
};

#endif
